@@ -49,16 +49,22 @@ dls = DLStudio(
                   use_gpu = True,
               )
 
-exp_skip = DLStudio.SkipConnections( dl_studio = dls )
+skip_con = DLStudio.SkipConnections( dl_studio = dls )
 
 #exp_skip.load_cifar_10_dataset_with_augmentation()
-exp_skip.load_cifar_10_dataset()
+skip_con.load_cifar_10_dataset()
 
-model = exp_skip.BMEnet(skip_connections=True, depth=32)
+model = skip_con.BMEnet(skip_connections=True, depth=32)
+
+number_of_learnable_params = sum(p.numel() for p in model.parameters() if p.requires_grad)
+print("\n\nThe number of learnable parameters in the model: %d\n\n" % number_of_learnable_params)
+
+num_layers = len(list(model.parameters()))
+print("\n\nThe number of layers in the model: %d\n\n" % num_layers)
 
 dls.show_network_summary(model)
 
-exp_skip.run_code_for_training(model)
+skip_con.run_code_for_training(model)
 
-exp_skip.run_code_for_testing(model)
+skip_con.run_code_for_testing(model)
 
